==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/Stacked100BarBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarBucketCalculator } from "./StackedBarBucketCalculator";
import { StackedBarSeries } from "./StackedBarSeries";
import { BarFragment } from "./BarFragment";
import { ScalerParams } from "./ScalerParams";
import { typeCast, markType } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var Stacked100BarBucketCalculator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarBucketCalculator, _super);
    function Stacked100BarBucketCalculator(a) {
        return _super.call(this, a) || this;
    }
    Stacked100BarBucketCalculator.prototype.getBucket = function (a) {
        return _super.prototype.getBucket.call(this, a);
    };
    Stacked100BarBucketCalculator.prototype.getBucket1 = function (a, b, c, d, e, f) {
        var g = typeCast(StackedBarSeries.$, this.c.db);
        var h = [NaN, NaN, NaN];
        var i = typeCast(BarFragment.$, a);
        if (i == null || i.logicalSeriesLink == null) {
            return h;
        }
        var j = a.valueColumn.item(c);
        var k = 0;
        var l = 0;
        var m = NaN;
        var n = NaN;
        var o = Number.NEGATIVE_INFINITY;
        var p = Number.POSITIVE_INFINITY;
        var q = g.getEffectiveViewport1(this.c);
        var r = Math.min(g.aax != null ? g.aax.length : 0, g.aaw != null ? g.aaw.length : 0);
        var s = c * this.d;
        var t = Math.min(s + this.d - 1, r - 1);
        if (s <= t) {
            for (var u = s; u <= t; ++u) {
                j = a.valueColumn.item(u);
                k = Math.abs(g.aax[u]) + g.aaw[u];
                if (j < l) {
                    p = Math.min(p, (i.logicalSeriesLink.a8._inner[u] + j) / k * 100);
                    o = Math.max(o, i.logicalSeriesLink.a8._inner[u] / k * 100);
                }
                else {
                    p = Math.min(p, i.logicalSeriesLink.a7._inner[u] / k * 100);
                    o = Math.max(o, (i.logicalSeriesLink.a7._inner[u] + j) / k * 100);
                }
                if (!isNaN_(m)) {
                    if (!isNaN_(p)) {
                        m = Math.min(m, p);
                        n = Math.max(n, p);
                    }
                    if (!isNaN_(o)) {
                        m = Math.min(m, o);
                        n = Math.max(n, o);
                    }
                }
                else {
                    m = p;
                    n = o;
                }
            }
        }
        var v = new ScalerParams(0, d, e, g.xAxis.ch, q);
        h = [f.h._inner[b - this.e][0], g.xAxis.el(n, v), g.xAxis.el(m, v)];
        return h;
    };
    Stacked100BarBucketCalculator.$t = markType(Stacked100BarBucketCalculator, 'Stacked100BarBucketCalculator', StackedBarBucketCalculator.$);
    return Stacked100BarBucketCalculator;
}(StackedBarBucketCalculator));
export { Stacked100BarBucketCalculator };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/Stacked100BarBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarBucketCalculator } from "./StackedBarBucketCalculator";
import { StackedBarSeries } from "./StackedBarSeries";
import { BarFragment } from "./BarFragment";
import { ScalerParams } from "./ScalerParams";
import { typeCast, markType } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var Stacked100BarBucketCalculator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarBucketCalculator, _super);
    function Stacked100BarBucketCalculator(a) {
        return _super.call(this, a) || this;
    }
    Stacked100BarBucketCalculator.prototype.getBucket = function (a) {
        return _super.prototype.getBucket.call(this, a);
    };
    Stacked100BarBucketCalculator.prototype.getBucket1 = function (a, b, c, d, e, f) {
        var g = typeCast(StackedBarSeries.$, this.c.db);
        var h = [NaN, NaN, NaN];
        var i = typeCast(BarFragment.$, a);
        if (i == null || i.logicalSeriesLink == null) {
            return h;
        }
        var j = a.valueColumn.item(c);
        var k = 0;
        var l = 0;
        var m = NaN;
        var n = NaN;
        var o = Number.NEGATIVE_INFINITY;
        var p = Number.POSITIVE_INFINITY;
        var q = g.getEffectiveViewport1(this.c);
        var r = Math.min(g.aa0 != null ? g.aa0.length : 0, g.aaz != null ? g.aaz.length : 0);
        var s = c * this.d;
        var t = Math.min(s + this.d - 1, r - 1);
        if (s <= t) {
            for (var u = s; u <= t; ++u) {
                j = a.valueColumn.item(u);
                k = Math.abs(g.aa0[u]) + g.aaz[u];
                if (j < l) {
                    p = Math.min(p, (i.logicalSeriesLink.a8._inner[u] + j) / k * 100);
                    o = Math.max(o, i.logicalSeriesLink.a8._inner[u] / k * 100);
                }
                else {
                    p = Math.min(p, i.logicalSeriesLink.a7._inner[u] / k * 100);
                    o = Math.max(o, (i.logicalSeriesLink.a7._inner[u] + j) / k * 100);
                }
                if (!isNaN_(m)) {
                    if (!isNaN_(p)) {
                        m = Math.min(m, p);
                        n = Math.max(n, p);
                    }
                    if (!isNaN_(o)) {
                        m = Math.min(m, o);
                        n = Math.max(n, o);
                    }
                }
                else {
                    m = p;
                    n = o;
                }
            }
        }
        var v = new ScalerParams(0, d, e, g.xAxis.ch, q);
        h = [f.h._inner[b - this.e][0], g.xAxis.el(n, v), g.xAxis.el(m, v)];
        return h;
    };
    Stacked100BarBucketCalculator.$t = markType(Stacked100BarBucketCalculator, 'Stacked100BarBucketCalculator', StackedBarBucketCalculator.$);
    return Stacked100BarBucketCalculator;
}(StackedBarBucketCalculator));
export { Stacked100BarBucketCalculator };
